AdRevenueEvent class final
Constructors
- AdRevenueEvent(AdsType type, String adUnitId, PrecisionType precision, String currencyCode, double valueMicros, {AdapterResponseInfo? loadedAdapterResponseInfo})
Properties
- adUnitId → String
-
final
- currencyCode → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- loadedAdapterResponseInfo → AdapterResponseInfo?
-
final
- precision → PrecisionType
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → AdsType
-
final
- valueMicros → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited