AdWithViewMounted mixin
Mixin that exposes isMounted getter to check if an inline view ad is currently mounted in a widget.
- Superclass constraints
Properties
- adUnitId → String
-
Identifies the source of Ads for your application.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMounted → bool
-
Returns true if the ad Id is already mounted in a WidgetAd managed
by the instanceManager.
no setter
- listener → AdWithViewListener
-
The AdWithViewListener for the ad.
finalinherited
- responseInfo ↔ ResponseInfo?
-
Contains information about the loaded request.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> -
Frees the plugin resources associated with this ad.
inherited
-
load(
) → Future< void> -
Starts loading this ad.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited