AdmobAdsServiceAbs<T extends Ad> class
abstract
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appOpenAdEnabled(bool enabled, {int? fixedInterval, bool enableAutoCache = true})
→ void
-
是否启动开屏广告
-
clearOpenAppAdVisibility(Object owner)
→ void
-
清除某个页面作用域下的开屏广告展示策略。
-
dispose()
→ Future<void>
-
释放广告
-
loadBannerAd({required BuildContext? context, AdOptions? options, AdRequest? request})
→ Future<BannerAd?>
-
获取banner广告
-
loadNativeAd({AdOptions? options, AdRequest? request})
→ Future<NativeAd?>
-
获取原生广告
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
preloadAds(int targetCount, {AdRequest? request})
→ Future<void>
-
预加载广告
-
setOpenAppAdVisibility(bool shouldShow, {required Object owner})
→ void
-
设置当前页面作用域下的开屏广告展示策略。
-
shouldShowOpenAppAd(bool shouldShow, {Object? blocker})
→ void
-
是否应该显示开屏广告
-
showAdIfAvailable({AdOptions? options, AdCallBack? adCallBack})
→ Future<void>
-
显示广告
如果有广告直接显示,如果没有,不做处理
-
showFullScreenAds({AdOptions? options, AdRequest? request, AdCallBack? adCallBack})
→ Future<void>
-
显示全屏广告
-
toString()
→ String
-
A string representation of this object.
inherited