AgeRestrictedTreatment enum
Values for RequestConfiguration.ageRestrictedTreatment.
Values
- unspecified → const AgeRestrictedTreatment
-
Indicates that no specific age restricted treatment signal applies to the ad request.
- child → const AgeRestrictedTreatment
-
Indicates that ad requests should receive child age treatment.
- teen → const AgeRestrictedTreatment
-
Indicates that ad requests should receive teen age treatment.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AgeRestrictedTreatment> - A constant List of the values in this enum, in order of their declaration.