PreloadCallback class

Callback interface for ad preloading events.

Constructors

PreloadCallback({void onAdPreloaded(String preloadId, ResponseInfo responseInfo)?, void onAdsExhausted(String preloadId)?, void onAdFailedToPreload(String preloadId, AdError error)?})
Creates a PreloadCallback.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
onAdFailedToPreload → void Function(String preloadId, AdError error)?
Callback when preloading an ad has failed.
final
onAdPreloaded → void Function(String preloadId, ResponseInfo responseInfo)?
Callback when an ad has been successfully preloaded.
final
onAdsExhausted → void Function(String preloadId)?
Callback when preloaded ads have been exhausted.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited