RewardedAdPreloader class abstract
A preloader for RewardedAds.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
destroy(
String preloadId) → Future< void> -
Destroys the preloader for the given
preloadId. -
destroyAll(
) → Future< void> - Destroys all preloaders of this format.
-
getConfiguration(
String preloadId) → Future< PreloadConfiguration?> -
Returns the configuration for the given
preloadId. -
getConfigurations(
) → Future< Map< String, PreloadConfiguration> > - Returns all active configurations.
-
getNumAdsAvailable(
String preloadId) → Future< int> -
Returns the number of preloaded ads available for the given
preloadId. -
isAdAvailable(
String preloadId) → Future< bool> -
Checks if an ad is available for the given
preloadId. -
pollAd(
String preloadId) → Future< RewardedAd?> -
Polls a preloaded ad for the given
preloadId. -
start(
{required String preloadId, required PreloadConfiguration preloadConfiguration, required PreloadCallback callback}) → Future< void> -
Starts preloading ads for the given
preloadIdandpreloadConfiguration.