BaseAdsService<T extends Ad> class abstract

Implemented types
Implementers

Constructors

BaseAdsService(AdUnit _unit)

Properties

adsType AdsType
no setter
adUnitId String
no setter
defaultRequest AdRequest
final
hashCode int
The hash code for this object.
no setterinherited
kLoadTimeout Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appOpenAdEnabled(bool enabled, {int? fixedInterval, bool enableAutoCache = true}) → void
是否启动开屏广告
override
clearOpenAppAdVisibility(Object owner) → void
清除某个页面作用域下的开屏广告展示策略。
override
dispose() Future<void>
释放广告
inherited
loadBannerAd({required BuildContext? context, AdOptions? options, AdRequest? request}) Future<BannerAd?>
获取banner广告
override
loadNativeAd({AdOptions? options, AdRequest? request}) Future<NativeAd?>
获取原生广告
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyAdRevenue(Ad ad, double valueMicros, PrecisionType precision, String currencyCode) → void
preloadAds(int targetCount, {AdRequest? request}) Future<void>
预加载广告
override
setOpenAppAdVisibility(bool shouldShow, {required Object owner}) → void
设置当前页面作用域下的开屏广告展示策略。
override
shouldShowOpenAppAd(bool shouldShow, {Object? blocker}) → void
是否应该显示开屏广告
override
showAdIfAvailable({AdOptions? options, AdCallBack? adCallBack}) Future<void>
显示广告 如果有广告直接显示,如果没有,不做处理
override
showFullScreenAds({AdOptions? options, AdRequest? request, AdCallBack? adCallBack}) Future<void>
显示全屏广告
override
toString() String
A string representation of this object.
inherited
unsupportedOperation(String operation) → Never

Operators

operator ==(Object other) bool
The equality operator.
inherited