InterstitialAdServiceImpl class final

Inheritance

Constructors

InterstitialAdServiceImpl(AdUnit _unit)

Properties

adsType AdsType
no setterinherited
adUnitId String
no setterinherited
defaultRequest AdRequest
finalinherited
hashCode int
The hash code for this object.
no setterinherited
kLoadTimeout Duration
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appOpenAdEnabled(bool enabled, {int? fixedInterval, bool enableAutoCache = true}) → void
是否启动开屏广告
inherited
clearOpenAppAdVisibility(Object owner) → void
清除某个页面作用域下的开屏广告展示策略。
inherited
clearPreloadedAds() → void
inherited
dispose() Future<void>
释放广告
inherited
getCallback(AdCallBack? adCallBack, {GenericAdEventCallback<InterstitialAd>? onAdShowedFullScreenContent, GenericAdEventCallback<InterstitialAd>? onAdDismissedFullScreenContent, dynamic onAdFailedToShowFullScreenContent(Ad ad, AdError error)?}) FullScreenContentCallback<InterstitialAd>
inherited
loadBannerAd({required BuildContext? context, AdOptions? options, AdRequest? request}) Future<BannerAd?>
获取banner广告
inherited
loadNativeAd({AdOptions? options, AdRequest? request}) Future<NativeAd?>
获取原生广告
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyAdRevenue(Ad ad, double valueMicros, PrecisionType precision, String currencyCode) → void
inherited
performLoadAd({AdRequest? request}) Future<InterstitialAd?>
override
performShow(InterstitialAd ad, {AdOptions? options, AdCallBack? adCallBack}) Future<void>
override
preloadAds(int targetCount, {AdRequest? request}) Future<void>
预加载广告
inherited
restorePreloadedAd(InterstitialAd ad, {bool toFront = false}) → void
inherited
setOpenAppAdVisibility(bool shouldShow, {required Object owner}) → void
设置当前页面作用域下的开屏广告展示策略。
inherited
shouldShowOpenAppAd(bool shouldShow, {Object? blocker}) → void
是否应该显示开屏广告
inherited
showAdIfAvailable({AdOptions? options, AdCallBack? adCallBack}) Future<void>
显示广告 如果有广告直接显示,如果没有,不做处理
inherited
showFullScreenAds({AdOptions? options, AdRequest? request, AdCallBack? adCallBack}) Future<void>
显示全屏广告
inherited
toString() String
A string representation of this object.
inherited
unsupportedOperation(String operation) → Never
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited