AdCallBack class
Constructors
- AdCallBack({dynamic onAdLoading(AdsType type)?, dynamic onAdLoaded(AdsType type, {int? cachedCount})?, dynamic onAdLoadFailed(AdsType type)?, dynamic onAdShown(AdsType type)?, dynamic onAdShowFailed(AdsType type)?, dynamic onAdDismissed(AdsType type, {bool? isEarnedReward})?, dynamic onAdClicked(AdsType type)?, dynamic onRewardEarned(AdsType type)?, dynamic onAdImpression(AdsType type)?})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onAdClicked → dynamic Function(AdsType type)?
-
广告被点击时触发
final
- onAdDismissed → dynamic Function(AdsType type, {bool? isEarnedReward})?
-
广告关闭时触发
final
- onAdImpression → dynamic Function(AdsType type)?
-
原生广告印象记录时触发
final
- onAdLoaded → dynamic Function(AdsType type, {int? cachedCount})?
-
广告加载成功时触发
final
- onAdLoadFailed → dynamic Function(AdsType type)?
-
广告加载失败时触发
final
- onAdLoading → dynamic Function(AdsType type)?
-
广告开始加载时触发
final
- onAdShowFailed → dynamic Function(AdsType type)?
-
广告展示失败时触发
final
- onAdShown → dynamic Function(AdsType type)?
-
广告开始展示时触发
final
- onRewardEarned → dynamic Function(AdsType type)?
-
激励广告奖励达成时触发
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited