AdOptions class
Constructors
- AdOptions({String? userId, String? customData, AdSize? bannerCustomSize, NativeTemplateStyle? nativeStyle})
-
const
Properties
-
final
- customData → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nativeStyle → NativeTemplateStyle?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverSideVerificationOptions → ServerSideVerificationOptions
-
no setter
- userId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited