AdsManager class final
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isMobileAdsInitializeCalled → bool
-
no setter
-
onAdRevenueChange
→ Stream<
AdRevenueEvent> -
no setter
Static Methods
-
getAdmobService(
AdUnit adUnit) → AdmobAdsServiceAbs< Ad> - 获取相应的广告服务
-
initAdmob(
{List< String> ? testDeviceIds}) → Future<bool> - 返回true表示初始化成功,false表示初始化失败 注意:如果已经初始化过,则不会重复初始化 可以通过调用removeAll方法释放所有广告服务 在应用启动时调用此方法进行初始化
-
notifyAdRevenue(
AdRevenueEvent adRevenue) → void -
openAdInspector(
) → void -
removeAdmobService(
AdUnit adUnit) → Future< void> - 清理某个广告实例
-
removeAll(
) → Future< void> - 释放全部广告
-
removeAllByType(
AdsType type) → Future< void> - 清理某个类型下的所有广告实例
-
setLogEnable(
bool enable) → void - 是否开启日志