PreloadConfiguration class
Configuration class for ad preloading.
Constructors
- PreloadConfiguration({required String adUnitId, AdRequest request = const AdRequest(), int bufferSize = 2})
-
Creates a PreloadConfiguration.
const
Properties
- adUnitId → String
-
The ad unit ID to preload ads for.
final
- bufferSize → int
-
The buffer size for the preloader.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- request → AdRequest
-
Targeting information used to fetch an Ad.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited