RequestConfiguration class
Contains targeting information that can be applied to all ad requests.
See relevant documentation at https://developers.google.com/ad-manager/mobile-ads-sdk/android/targeting#requestconfiguration.
Constructors
-
RequestConfiguration({String? maxAdContentRating, @Deprecated('Use ageRestrictedTreatment instead.') int? tagForChildDirectedTreatment, @Deprecated('Use ageRestrictedTreatment instead.') int? tagForUnderAgeOfConsent, List<
String> ? testDeviceIds, AgeRestrictedTreatment? ageRestrictedTreatment}) - Creates a RequestConfiguration.
Properties
- ageRestrictedTreatment → AgeRestrictedTreatment?
-
The age treatment to apply to ad requests. Consult your own legal
counsel to determine the age treatment settings for your users based
on your legal and regulatory requirements. For more information on this
setting, review
https://developers.google.com/admob/flutter/targeting#set_the_age_treatment
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAdContentRating → String?
-
Maximum content rating that will be shown.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tagForChildDirectedTreatment → int?
-
Whether to tag as child directed.
final
- tagForUnderAgeOfConsent → int?
-
Whether to tag as under age of consent.
final
-
testDeviceIds
→ List<
String> ? -
List of test device ids to set.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited